@@ -16,6 +16,8 @@ describe Rouge::Lexers::Terraform do
 
     it 'guesses by filename' do
       assert_guess :filename => 'foo.tf'
+      assert_guess :filename => 'foo.tfvars'
+      assert_guess :filename => 'foo.tofu'
       deny_guess   :filename => 'foo'
     end
 
